==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/BuildTriggerCauseFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildTriggerCauseFluent<A extends io.fabric8.openshift.api.model.BuildTriggerCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBitbucketWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.BitbucketWebHookCause getBitbucketWebHook();
  public io.fabric8.openshift.api.model.BitbucketWebHookCause buildBitbucketWebHook();
  public A withBitbucketWebHook(io.fabric8.openshift.api.model.BitbucketWebHookCause bitbucketWebHook);
  public java.lang.Boolean hasBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> withNewBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> withNewBitbucketWebHookLike(io.fabric8.openshift.api.model.BitbucketWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> editBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> editOrNewBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> editOrNewBitbucketWebHookLike(io.fabric8.openshift.api.model.BitbucketWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildGenericWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GenericWebHookCause getGenericWebHook();
  public io.fabric8.openshift.api.model.GenericWebHookCause buildGenericWebHook();
  public A withGenericWebHook(io.fabric8.openshift.api.model.GenericWebHookCause genericWebHook);
  public java.lang.Boolean hasGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> withNewGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> withNewGenericWebHookLike(io.fabric8.openshift.api.model.GenericWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> editGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> editOrNewGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> editOrNewGenericWebHookLike(io.fabric8.openshift.api.model.GenericWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildGithubWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GitHubWebHookCause getGithubWebHook();
  public io.fabric8.openshift.api.model.GitHubWebHookCause buildGithubWebHook();
  public A withGithubWebHook(io.fabric8.openshift.api.model.GitHubWebHookCause githubWebHook);
  public java.lang.Boolean hasGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> withNewGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> withNewGithubWebHookLike(io.fabric8.openshift.api.model.GitHubWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> editGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> editOrNewGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> editOrNewGithubWebHookLike(io.fabric8.openshift.api.model.GitHubWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildGitlabWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GitLabWebHookCause getGitlabWebHook();
  public io.fabric8.openshift.api.model.GitLabWebHookCause buildGitlabWebHook();
  public A withGitlabWebHook(io.fabric8.openshift.api.model.GitLabWebHookCause gitlabWebHook);
  public java.lang.Boolean hasGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> withNewGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> withNewGitlabWebHookLike(io.fabric8.openshift.api.model.GitLabWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> editGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> editOrNewGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> editOrNewGitlabWebHookLike(io.fabric8.openshift.api.model.GitLabWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildImageChangeBuild instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ImageChangeCause getImageChangeBuild();
  public io.fabric8.openshift.api.model.ImageChangeCause buildImageChangeBuild();
  public A withImageChangeBuild(io.fabric8.openshift.api.model.ImageChangeCause imageChangeBuild);
  public java.lang.Boolean hasImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> withNewImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> withNewImageChangeBuildLike(io.fabric8.openshift.api.model.ImageChangeCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> editImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> editOrNewImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> editOrNewImageChangeBuildLike(io.fabric8.openshift.api.model.ImageChangeCause item);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public interface BitbucketWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<N>>{
    public N and();
    public N endBitbucketWebHook();
    
  }
  public interface GenericWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.GenericWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<N>>{
    public N and();
    public N endGenericWebHook();
    
  }
  public interface GithubWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<N>>{
    public N and();
    public N endGithubWebHook();
    
  }
  public interface GitlabWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.GitLabWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<N>>{
    public N and();
    public N endGitlabWebHook();
    
  }
  public interface ImageChangeBuildNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ImageChangeCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<N>>{
    public N and();
    public N endImageChangeBuild();
    
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/BuildTriggerCauseFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildTriggerCauseFluent<A extends io.fabric8.openshift.api.model.BuildTriggerCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBitbucketWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.BitbucketWebHookCause getBitbucketWebHook();
  public io.fabric8.openshift.api.model.BitbucketWebHookCause buildBitbucketWebHook();
  public A withBitbucketWebHook(io.fabric8.openshift.api.model.BitbucketWebHookCause bitbucketWebHook);
  public java.lang.Boolean hasBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> withNewBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> withNewBitbucketWebHookLike(io.fabric8.openshift.api.model.BitbucketWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> editBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> editOrNewBitbucketWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<A> editOrNewBitbucketWebHookLike(io.fabric8.openshift.api.model.BitbucketWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildGenericWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GenericWebHookCause getGenericWebHook();
  public io.fabric8.openshift.api.model.GenericWebHookCause buildGenericWebHook();
  public A withGenericWebHook(io.fabric8.openshift.api.model.GenericWebHookCause genericWebHook);
  public java.lang.Boolean hasGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> withNewGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> withNewGenericWebHookLike(io.fabric8.openshift.api.model.GenericWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> editGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> editOrNewGenericWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<A> editOrNewGenericWebHookLike(io.fabric8.openshift.api.model.GenericWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildGithubWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GitHubWebHookCause getGithubWebHook();
  public io.fabric8.openshift.api.model.GitHubWebHookCause buildGithubWebHook();
  public A withGithubWebHook(io.fabric8.openshift.api.model.GitHubWebHookCause githubWebHook);
  public java.lang.Boolean hasGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> withNewGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> withNewGithubWebHookLike(io.fabric8.openshift.api.model.GitHubWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> editGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> editOrNewGithubWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<A> editOrNewGithubWebHookLike(io.fabric8.openshift.api.model.GitHubWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildGitlabWebHook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GitLabWebHookCause getGitlabWebHook();
  public io.fabric8.openshift.api.model.GitLabWebHookCause buildGitlabWebHook();
  public A withGitlabWebHook(io.fabric8.openshift.api.model.GitLabWebHookCause gitlabWebHook);
  public java.lang.Boolean hasGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> withNewGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> withNewGitlabWebHookLike(io.fabric8.openshift.api.model.GitLabWebHookCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> editGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> editOrNewGitlabWebHook();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<A> editOrNewGitlabWebHookLike(io.fabric8.openshift.api.model.GitLabWebHookCause item);
  
  /**
   * This method has been deprecated, please use method buildImageChangeBuild instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ImageChangeCause getImageChangeBuild();
  public io.fabric8.openshift.api.model.ImageChangeCause buildImageChangeBuild();
  public A withImageChangeBuild(io.fabric8.openshift.api.model.ImageChangeCause imageChangeBuild);
  public java.lang.Boolean hasImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> withNewImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> withNewImageChangeBuildLike(io.fabric8.openshift.api.model.ImageChangeCause item);
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> editImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> editOrNewImageChangeBuild();
  public io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<A> editOrNewImageChangeBuildLike(io.fabric8.openshift.api.model.ImageChangeCause item);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface BitbucketWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.BitbucketWebHookNested<N>>{
    public N and();
    public N endBitbucketWebHook();
    
  }
  public interface GenericWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.GenericWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GenericWebHookNested<N>>{
    public N and();
    public N endGenericWebHook();
    
  }
  public interface GithubWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.GitHubWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GithubWebHookNested<N>>{
    public N and();
    public N endGithubWebHook();
    
  }
  public interface GitlabWebHookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.GitLabWebHookCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.GitlabWebHookNested<N>>{
    public N and();
    public N endGitlabWebHook();
    
  }
  public interface ImageChangeBuildNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ImageChangeCauseFluent<io.fabric8.openshift.api.model.BuildTriggerCauseFluent.ImageChangeBuildNested<N>>{
    public N and();
    public N endImageChangeBuild();
    
  }
  
}
